@@ -1,13 +1,9 @@
 from d3heatmap import d3heatmap
 
-from d3heatmap.utils.adjmat_vec import (
-    vec2adjmat,
-    adjmat2vec,
-    )
 
 __author__ = 'Erdogan Tasksen'
 __email__ = 'erdogant@gmail.com'
-__version__ = '0.1.7'
+__version__ = '0.2.0'
 
 # module level doc-string
 __doc__ = """
